@@ -80,11 +80,19 @@ void k9vamps::addSubpicture(uint id) {
 void k9vamps::addAudio(uint id) {
     int cpt=1;
     for (uint i=0;i <8;i++)
-	if (audio_track_map[i] !=0) cpt++;
+        if (audio_track_map[i] !=0) cpt++;
 
     audio_track_map[id-1]=cpt;
 }
 
+void k9vamps::addAudio(uint id,uint newId) {
+    if (newId==0) 
+        addAudio(id);
+    else 
+        audio_track_map[id-1]=newId;
+}
+
+
 void k9vamps::setInputSize(uint64_t size) {
     ps_size=size;
 }
@@ -93,6 +101,10 @@ void k9vamps::setVapFactor(float factor) {
     vap_fact=factor;
 }
 
+void k9vamps::setSaveImage(k9SaveImage *m_save) {
+    m_saveImage=m_save;
+}
+
 void k9vamps::reset() {
     m_preserve=true;
     bytes_read =0;
@@ -134,7 +146,7 @@ void k9vamps::reset() {
 }
 
 k9vamps::k9vamps(k9DVDBackup *dvdbackup) {
-
+    m_saveImage=NULL;
     m_dvdbackup=dvdbackup;
     reset();
     m_requant=NULL;
@@ -173,7 +185,7 @@ void k9vamps::run () {
     vobuf = (uchar*) malloc (vbuf_size);
 
     if (vibuf == NULL || vobuf == NULL)
-        fatal ("Allocation of video buffers failed: %s", strerror (errno));
+        fatal (QString("Allocation of video buffers failed: %1").arg(strerror (errno)));
 
 
     // actually do vaporization
@@ -280,7 +292,8 @@ void k9vamps::flush (void) {
     } 
     if (m_output != NULL)
 	m_output->writeBlock((const char*) wbuf,size);
-
+    if (m_saveImage !=NULL) 
+        m_saveImage->addData(wbuf,size);
     wptr           = wbuf;
     bytes_written += size;
     mutex.unlock();
@@ -344,32 +357,33 @@ int k9vamps::check_video_packet (uchar *ptr) {
     vid_packet_start_code |= (uint32_t) (ptr [3]);
 
     if (vid_packet_start_code != 0x000001e0)
-        fatal ("Bad video packet start code at %llu: %08lx",
-               rtell (ptr), vid_packet_start_code);
+        fatal(QString ("Bad video packet start code at %1: %2").arg(rtell(ptr)).arg(vid_packet_start_code,0,16));
 
     vid_packet_length  = ptr [4] << 8;
     vid_packet_length |= ptr [5];
     vid_packet_length += 6;
 
     if ((ptr [6] & 0xc0) != 0x80)
-        fatal ("Not an MPEG2 video packet at %llu", rtell (ptr));
+        fatal (QString("Not an MPEG2 video packet at %1").arg(rtell (ptr)));
 
     if (ptr [7]) {
         if ((ptr [7] & 0xc0) != 0xc0)
-           fatal ("First video packet in sequence starting at %llu misses PTS or DTS, flags=%02x", rtell (ptr), ptr [7]);
-
-        sequence_header_code  = (uint32_t) (ptr [6 + 3 + ptr [8] + 0]) << 24;
-        sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 1]) << 16;
-        sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 2]) <<  8;
-        sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 3]);
-
-        if (sequence_header_code == 0x000001b3) {
-            rc = 1;
-        } else {
-            //fprintf (stderr, "Start of GOP at %llu not on sector boundary\n",
-            //         rtell (ptr + 6 + 3 + ptr [8]));
-            sequence_headers++;
+           qDebug (QString("First video packet in sequence starting at %1 misses PTS or DTS, flags=%2").arg(rtell (ptr)).arg(ptr [7]));
+        else {
+            sequence_header_code  = (uint32_t) (ptr [6 + 3 + ptr [8] + 0]) << 24;
+            sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 1]) << 16;
+            sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 2]) <<  8;
+            sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 3]);
+    
+            if (sequence_header_code == 0x000001b3) {
+                rc = 1;
+            } else {
+                //fprintf (stderr, "Start of GOP at %llu not on sector boundary\n",
+                //         rtell (ptr + 6 + 3 + ptr [8]));
+                sequence_headers++;
+            }
         }
+        
     }
 
     pad_packet_length = 0;
@@ -385,18 +399,17 @@ int k9vamps::check_video_packet (uchar *ptr) {
         pad_packet_start_code |= (uint32_t) (ptr [3]);
 
         if (pad_packet_start_code != 0x000001be)
-            fatal ("Bad padding packet start code at %llu: %08lx",
-                   rtell (ptr + vid_packet_length), pad_packet_start_code);
-
-        pad_packet_length  = ptr [4] << 8;
-        pad_packet_length |= ptr [5];
-        pad_packet_length += 6;
+            qDebug (QString("Bad padding packet start code at %1: %2").arg(rtell (ptr + vid_packet_length)).arg(pad_packet_start_code));
+        else {
+            pad_packet_length  = ptr [4] << 8;
+            pad_packet_length |= ptr [5];
+            pad_packet_length += 6;
+        }
     }
 
     // length of video packet plus padding packet must always match sector size
     if (14 + vid_packet_length + pad_packet_length != SECT_SIZE)
-        fatal ("Bad video packet length at %llu: %d",
-               rtell (ptr), vid_packet_length);
+        qDebug (QString("Bad video packet length at %1: %2").arg(rtell (ptr)).arg(vid_packet_length));
 
     return rc;
 }
@@ -622,8 +635,7 @@ void k9vamps::vap_leader () {
             data_length |= ptr [5];
 
             if (14 + data_length != SECT_SIZE - 6)
-                fatal ("Bad padding packet length at %llu: %d",
-                       rtell (ptr), data_length);
+                fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
 
             break;
 
@@ -666,8 +678,7 @@ void k9vamps::vap_trailer (int length) {
             data_length |= ptr [5];
 
             if (14 + data_length != SECT_SIZE - 6)
-                fatal ("Bad padding packet length at %llu: %d",
-                       rtell (ptr), data_length);
+                fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
         } else {
             copy (SECT_SIZE);
         }
@@ -787,8 +798,7 @@ int k9vamps::vap_phase1 (void) {
             data_length |= ptr [5];
 
             if (14 + data_length != SECT_SIZE - 6)
-                fatal ("Bad padding packet length at %llu: %d",
-                       rtell (ptr), data_length);
+                fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
 
             break;
 
@@ -924,8 +934,7 @@ void k9vamps::vap_phase2 (int seq_length) {
             data_length |= ptr [5];
 
             if (14 + data_length != SECT_SIZE - 6)
-                fatal ("Bad padding packet length at %llu: %d",
-                       rtell (ptr), data_length);
+                fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
 
             break;
 
@@ -1054,13 +1063,8 @@ void k9vamps::abort() {
 
 // this is a *very* sophisticated kind of error handling :-)
 void
-k9vamps::fatal (char *fmt, ...) {
-    char tmp[255];
-    va_list ap;
-    va_start (ap, fmt);
-    vsprintf (tmp,fmt, ap);
-    va_end (ap);
-    m_errMsg.setLatin1(tmp);
+k9vamps::fatal (QString msg) {
+    m_errMsg=msg;
     m_error=true;
     if (m_requant !=NULL)
         m_requant->terminate();
