@@ -26,6 +26,8 @@
 #include <qmutex.h>
 #include "kdecmpeg2.h"
 
+class k9DrawImage;
+
 class k9BackupDlg : public backupDlg
 {
   Q_OBJECT
@@ -59,6 +61,7 @@ private :
   QMutex mutex;
   bool m_playmovie;
   uint m_cpt;
+  k9DrawImage *m_wimage;
 protected:
   /*$PROTECTED_FUNCTIONS$*/
   void bAbortClick();
