@@ -217,7 +217,7 @@ int k9DVD::get_title_name(const char* dvd_device, char* title) {
     return 0;
 }
 
-QString k9DVD::lang_name(const QString& code) {
+QString k9DVD::lang_name(const QString& code,const QString & name) {
     QString c;
     int i=0;
     lng arrLng[] = {
@@ -252,8 +252,15 @@ QString k9DVD::lang_name(const QString& code) {
     c=i18n("Unknown");
     for (i=0 ; arrLng[i].code[0]!=0;i++) {
         lng l =arrLng[i];
-        if (strcmp(code.latin1(),l.code)==0) {
-            c = l.name;
+        if (name=="") {
+            if (strcmp(code.latin1(),l.code)==0) {
+                c = l.name;
+            }
+        } else {
+            if (strcmp(name.latin1(),l.name)==0) {
+                c = l.code;
+            }
+
         }
     }
     return c;
@@ -337,10 +344,12 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
         return 2;
     }
 
-    k9Ifo2 kifo_zero(&m_dvd),kifo(&m_dvd);
-    kifo_zero.openIFO( 0);
+//    k9Ifo2 kifo_zero(&m_dvd),kifo(&m_dvd);
+//    kifo_zero.openIFO( 0);
+    k9Ifo2 *kifo_zero= m_dvd.getIfo(0);
+    k9Ifo2 *kifo;
 
-    ifo_zero = kifo_zero.getIFO();
+    ifo_zero = kifo_zero->getIFO();
     if ( !ifo_zero ) {
         c=tr2i18n("Can't open main ifo!\n");
         setError(c);
@@ -360,8 +369,8 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
 
     for (int ts=1;ts <=m_titlesetCount;ts++) {
         tt_srpt = ifo_zero->tt_srpt;
-        kifo.openIFO(ts);
-        ifo = kifo.getIFO();
+        kifo=m_dvd.getIfo(ts);
+        ifo = kifo->getIFO();
         if (ifo==NULL)
             continue;
         //add the titleset in the titleset list
@@ -451,16 +460,18 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                         l_auds->id = 1+ ((pgc->audio_control[i]>>8) & 0x7) ;
                         //this only true for AC3 streams
 			l_auds->m_streamId = (pgc->audio_control[i]>>8);
-                        
-                        //JMPaudio_attr = &vtsi_mat->vts_audio_attr[i];
-                        audio_attr = &vtsi_mat->vts_audio_attr[l_auds->id-1];
+                        audio_attr = &vtsi_mat->vts_audio_attr[i];
+                        //dts stream starts at 0x88
+                        if (audio_attr->audio_format==6)
+                            l_auds->m_streamId +=8;
+                        //JMPaudio_attr = &vtsi_mat->vts_audio_attr[l_auds->id-1];
                         sprintf(lang_code, "%c%c", audio_attr->lang_code>>8, audio_attr->lang_code & 0xff);
                         if (!lang_code[0]) {
                             lang_code[0] = 'x';
                             lang_code[1] = 'x';
                         }
                         l_auds->langCod=lang_code;
-                        l_auds->language=lang_name(l_auds->langCod);
+                        l_auds->language=lang_name(l_auds->langCod,"");
 			if (l_auds->language==i18n("Unknown"))
 				l_auds->langCod="xx";
 
@@ -605,7 +616,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                         }
                         //JMP : l_sub->setselected(!titleIndexed);
                         l_sub->langCod=lang_code;
-                        l_sub->language=lang_name(lang_code);
+                        l_sub->language=lang_name(lang_code,"");
                         l_sub->content= (*m_lsubpType.at(subp_attr->code_extension));
                     }
                 }
@@ -614,12 +625,12 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
             }
 
         }
-        kifo.closeIFO();
+        //kifo.closeIFO();
     }
     m_menuSize=0;
     for (j=0;j<100;j++)
         m_menuSize+=menuSizes[j];
-    kifo_zero.closeIFO();
+    //kifo_zero.closeIFO();
 
     if (!_quickScan)
     	delete m_progressDlg;
