@@ -49,11 +49,20 @@ k9DVDAuthor::k9DVDAuthor(QObject *DVDStruct,const char* name,const QStringList&
     xml=NULL;
     cancelled=false;
     error=false;
+    progress = new k9Progress(qApp->mainWidget(),"progress",NULL);
+    files.setAutoDelete(true);
 
 }
 k9DVDAuthor::~k9DVDAuthor() {
+    QPtrListIterator <KTempFile> it (files);
+    KTempFile *file;
+    while ( (file = it.current()) != 0 ) {
+        ++it;
+        file->file()->remove();
+    }
     if (xml!=NULL)
         delete xml;
+
 }
 /** No descriptions */
 void k9DVDAuthor::createXML() {
@@ -71,9 +80,6 @@ void k9DVDAuthor::createXML() {
     root.appendChild(vmgm);
     addMenus(vmgm);
 
-    inject = locateLocal("tmp", "k9copy/k9v" + (QTime::currentTime()).toString("hhmmss"));
-
-
     m_totalPartSize=0;
 
     m_forced=0;
@@ -114,12 +120,13 @@ void k9DVDAuthor::createXML() {
 
     QString x = xml->toString();
     
-    QFile file(  locateLocal("tmp", "k9copy/k9author.xml" ));
-    if ( file.open( IO_WriteOnly ) ) {
-        QTextStream stream( &file );
+    //QFile file(  locateLocal("tmp", "k9copy/k9author.xml" ));
+    
+   // if ( file.open( IO_WriteOnly ) ) {
+        QTextStream stream( m_xml->file() );
         xml->save(stream,1);
-        file.close();
-    }
+        m_xml->file()->close();
+   // }
 }
 
 void k9DVDAuthor::addMenus(QDomElement &titleSet) {
@@ -225,17 +232,19 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
         pre.appendChild(precmd);
 
         //create palette for subpictures
-        palette.sprintf("palette%d.yuv",l_track->getnumTitle());
-        palette= locateLocal("tmp", "k9copy/k9" +palette);
-        QFile file(palette);
-        if ( file.open( IO_WriteOnly ) ) {
-            QTextStream stream( &file );
-            for (j=0;j<16;j++) {
-                l_track->getpalette(j,c);
-                stream << c+"\n";
-            }
-            file.close();
+        KTempFile *paletteFile=new KTempFile(locateLocal("tmp", "k9copy/k9p"), ".yuv");
+        files.append(paletteFile);
+        paletteFile->setAutoDelete(false);
+        palette=paletteFile->name();
+
+        //palette.sprintf("palette%d.yuv",l_track->getnumTitle());
+        //palette= locateLocal("tmp", "k9copy/k9" +palette);
+        QTextStream stream( paletteFile->file() );
+        for (j=0;j<16;j++) {
+            l_track->getpalette(j,c);
+            stream << c+"\n";
         }
+        paletteFile->file()->close();
 
         t=xml->createElement("titles");
         titleSet.appendChild(t);
@@ -386,41 +395,42 @@ void k9DVDAuthor::author() {
 
     bool burnOk=false;
     //nettoyage du répertoire de sortie
-    clearOutput(workDir+"dvd");
+    k9Tools::clearOutput(workDir+"dvd");
 
     time = new QTime(0,0);
     time->start();
 
-    //progress= new QProgressDialog ("DVDAuthor",i18n("Cancel"),100,qApp->mainWidget(),"progress",true,0);
-    progress = new k9Progress(qApp->mainWidget(),"progress",NULL);
     progress->setTitle(i18n("Authoring"));
     progress->setCaption(i18n("k9Copy - Backup progression"));
     progress->setProgress(0,100);
     //progress->show();
+
+    m_xml=new KTempFile(locateLocal("tmp", "k9copy/k9a"),".xml");
+
+    m_inject=new KTempFile(locateLocal("tmp", "k9copy/k9v"),".inj");
+    inject=m_inject->name();
+
     if (!cancelled && !error)
         createXML();
-    if (error || cancelled)
-        delete progress;
+//    if (error || cancelled)
+//        delete progress;
 
     //run dvdauthor
     if (!cancelled  && !error) {
         QString c("dvdauthor");
         proc=progress->getProcess();//  new QProcess(c,0);
-        proc->addArgument(c);
-        proc->addArgument("-x");
-        proc->addArgument( locateLocal("tmp", "k9copy/k9author.xml"));
-        connect( proc, SIGNAL(readyReadStderr()),
-                 this, SLOT(DVDAuthorStderr()) );
-        connect( proc, SIGNAL(readyReadStdout()),
-                 this, SLOT(DVDAuthorStdout()) );
+        *proc << c << "-x" <<  m_xml->name();  //locateLocal("tmp", "k9copy/k9author.xml");
+        connect( proc, SIGNAL(receivedStderr(KProcess *, char *, int)),
+                 this, SLOT(DVDAuthorStderr(KProcess *, char *, int )) );
+        connect( proc, SIGNAL(receivedStdout(KProcess *, char *, int )),
+                 this, SLOT(DVDAuthorStdout(KProcess *, char *, int)) );
         //    connect(progress, SIGNAL(cancelled()), this, SLOT(stopProcess()));
 
         m_copied=0;
         m_lastPos=0;
         //if (m_totalSize >k9DVDSize::getMaxSize())
         //    m_totalSize=k9DVDSize::getMaxSize();
-        QDir dir(workDir);
-        proc->setWorkingDirectory(dir);
+        proc-> setWorkingDirectory(workDir);
         int result=progress->execute();
         if ( result==-1 ) {
             KMessageBox::error( 0,  tr2i18n("Dvdauthor error :\n") + lastMsg,tr2i18n("authoring"));
@@ -440,20 +450,24 @@ void k9DVDAuthor::author() {
             }
         }
         //        delete proc;
-        delete progress;
+ //       delete progress;
         if (!burnOk)
             error=true;
     }
 
     delete time;
+    m_xml->file()->remove();
+    m_inject->file()->remove();
+    delete m_inject;
+    delete m_xml;
 }
 
 
 /** No descriptions */
-void k9DVDAuthor::DVDAuthorStderr() {
-    //QString c(proc->readStderr());
+void k9DVDAuthor::DVDAuthorStderr(KProcess *proc, char *buffer, int buflen ) {
 
-    QString m_stderr(proc->readStderr());
+    //QString m_stderr(proc->readStderr());
+    QString m_stderr=QString::fromLatin1(buffer, buflen);
     float m_percent;
     QString m_remain;
 
@@ -510,10 +524,18 @@ void k9DVDAuthor::DVDAuthorStderr() {
         }
     }
 
+    pos=m_stderr.find("INFOIMAGE:");
+    if (pos!=-1) {
+       progress->setImage(m_stderr.mid(pos+10));
+    } 
+
+
+
 }
 
-void k9DVDAuthor::DVDAuthorStdout() {
-    QString c(proc->readStdout());
+void k9DVDAuthor::DVDAuthorStdout(KProcess *proc, char *buffer, int buflen) {
+    QString c=QString::fromLatin1( buffer,buflen);
+    //(proc->readStdout());
     int pos;
     pos=c.find("STAT");
     if (pos!=-1) {
@@ -525,29 +547,10 @@ void k9DVDAuthor::DVDAuthorStdout() {
 
 /** No descriptions */
 void k9DVDAuthor::stopProcess() {
-    proc->tryTerminate();
+    proc->kill();
     cancelled=true;
 }
 
-void k9DVDAuthor::clearOutput(QString name) {
-    QDir dir(name);
-    //delete files in directory
-    QStringList lst = dir.entryList( "*",QDir::Files |QDir::Hidden );
-    for ( QStringList::Iterator it = lst.begin(); it != lst.end(); ++it ) {
-        QString c(( *it ).latin1() );
-        dir.remove (c);
-    }
-    //scanning subdir
-    QStringList lstdir = dir.entryList( "*",QDir::Dirs );
-    for ( QStringList::Iterator it = lstdir.begin(); it != lstdir.end(); ++it ) {
-        QString c(( *it ).latin1() );
-        if ((c!=".") && c!="..") {
-            clearOutput(dir.absFilePath(c));
-            dir.rmdir(c);
-        }
-    }
-
-}
 /** Read property of bool burnDVD. */
 const bool& k9DVDAuthor::getburnDVD() {
     return burnDVD;
