@@ -32,6 +32,7 @@
 #include "k9config.h"
 #include "k9updatefactor.h"
 #include "k9haldevice.h"
+#include "k9titleencopt.h"
 #include <kselect.h>
 #include <kcombobox.h>
 #include <qtextbrowser.h>
@@ -64,8 +65,8 @@
 #include <kdeversion.h>
 #include <qlistbox.h>
 #include <qtoolbox.h>
-
-
+#include <qregion.h>
+#include <qbitmap.h>
 
 
 k9DVDListItem::k9DVDListItem(QObject *DVD,ckLvItem *List,eStreamType type)
@@ -98,7 +99,7 @@ k9Main::k9Main(QWidget* parent, const char* name, const QStringList &sl)
     : MainDlg(parent,name),pxVideo((const char **) img_video), pxSound((const char **) img_sound),
     pxText((const char **) img_text)
 {
-
+  m_parent=(k9Copy*)parent;
   QImage img;
   img.loadFromData( img_chapter, sizeof( img_chapter ), "PNG" );
   pxChapter.convertFromImage( img);
@@ -124,7 +125,7 @@ k9Main::k9Main(QWidget* parent, const char* name, const QStringList &sl)
   bInputOpenDir->setPixmap(SmallIcon("folder_open"));
   emit SelectionChanged(NULL,true);
   m_update=new k9UpdateFactor(this,"");
-  connect(m_update,SIGNAL(updateFactor_internal()),this,SLOT(updateFactor_internal()));
+  connect(m_update,SIGNAL(updateFactor_internal()),this,SLOT(updateFactor_internal()));  
 }
 
 
@@ -157,13 +158,13 @@ int ckLvItem::compare ( QListViewItem * i, int col, bool ascending ) const
   uint id,id2;
   if (col==0)
   {
-    switch(depth())
+    switch(this->objectType)
     {
-    case 1:
+    case TITLESET:
       titleset1=(k9DVDTitleset*)obj;
       titleset2=(k9DVDTitleset*)litem->obj;
       return titleset1->getnum() -titleset2->getnum();
-    case 3:
+    case STREAM:
       l=(ckLvItem*)this;
       id=streamType*100;
       id2=litem->streamType*100;
@@ -189,31 +190,32 @@ int ckLvItem::compare ( QListViewItem * i, int col, bool ascending ) const
 
       return k9Main::compare(id,id2);
       break;
-    case 4:
+    case CHAPTER:
       l=(ckLvItem*)this;
       k9DVDChapter *ch1=(k9DVDChapter*)l->obj;
       k9DVDChapter *ch2=(k9DVDChapter*)litem->obj;
       return k9Main::compare(ch1->getnum()+ch1->getTitle()->getId()*1000 ,ch2->getnum()+ch2->getTitle()->getId()*1000);
+      break;
     }
   }
 
   if (col ==1)
   {
-    switch (depth())
+    switch (this->objectType)
     {
-    case 1:
+    case TITLESET:
       titleset1=(k9DVDTitleset*)obj;
       titleset2=(k9DVDTitleset*)litem->obj;
       return k9Main::compare(titleset1->getsize(),titleset2->getsize());
       break;
-    case 3:
+    case STREAM:
       double size1,size2;
       l =(ckLvItem*)this;
       size1=l->getstreamSize();
       size2=litem->getstreamSize();
       return k9Main::compare(size1,size2);
       break;
-    case 4:
+    case CHAPTER:
       l=(ckLvItem*)this;
       k9DVDChapter *ch1=(k9DVDChapter*)l->obj;
       k9DVDChapter *ch2=(k9DVDChapter*)litem->obj;
@@ -261,13 +263,13 @@ int LvItem::compare ( QListViewItem * i, int col, bool ascending ) const
     return -1;
   LvItem *litem = (LvItem*)i;
   k9DVDTitle *title1,*title2;
-  if (col ==1 && depth()==2)
+  if (col ==1 && objectType==TITLE)
   {
     title1=(k9DVDTitle*)obj;
     title2=(k9DVDTitle*)litem->obj;
     return k9Main::compare(title1->gettotalsize_mb(),title2->gettotalsize_mb());
   }
-  if (col==0 && depth()==2)
+  if (col==0 && objectType==TITLE)
   {
     title1=(k9DVDTitle*)obj;
     title2=(k9DVDTitle*)litem->obj;
@@ -284,34 +286,34 @@ void ckLvItem::paintCell ( QPainter * p, const QColorGroup & cg, int column, int
     p->eraseRect(0,0,width,height());
     QFont f(p->font());
 
-    switch (depth())
+    switch (objectType)
     {
-    case 1:
+    case TITLESET:
       {
         k9DVDTitleset *titleset=(k9DVDTitleset*)obj;
         f.setBold(true);
         p->setFont(f);
-        p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,titleset->getsize_mb()+" " +i18n("mb"));
+        p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,titleset->getsize_mb()+" " +i18n("MB"));
         break;
       }
-    case 3:
+    case STREAM:
       {
         if ( ! mainDlg->getquickScan())
         {
           double size=getstreamSize();
           QString c;
           c.sprintf("%.2f ",size);
-          p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("mb"));
+          p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("MB"));
         }
         break;
       }
-    case 4 :
+    case CHAPTER :
       {
         k9DVDChapter *chapter=(k9DVDChapter*) obj;
         double size=(double)chapter->getsectors()/512;
         QString c;
         c.sprintf("%.2f ",size);
-        p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("mb"));
+        p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("MB"));
       }
       break;
     default:
@@ -325,13 +327,13 @@ void ckLvItem::paintCell ( QPainter * p, const QColorGroup & cg, int column, int
 
 void LvItem::paintCell ( QPainter * p, const QColorGroup & cg, int column, int width, int align )
 {
-  if (column==1 && depth()==2)
+  if (column==1 && objectType==TITLE)
   {
     p->eraseRect(0,0,width,height());
     k9DVDTitle * title=(k9DVDTitle*)obj;
     QString c;
     c.sprintf("%.2f ",title->gettotalsize_mb());
-    p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("mb"));
+    p->drawText(0,0,width,height(),Qt::AlignRight | Qt::AlignVCenter ,c+i18n("MB"));
   }
   else
     QListViewItem::paintCell(p,cg,column,width,align);
@@ -343,12 +345,12 @@ void ckLvItem::stateChange(bool state)
   {
     if (mainDlg->getupdating())
       return;
-    switch (depth())
+    switch (objectType)
     {
-    case 0 :
+    case ROOT :
       mainDlg->checkAll(state);
       break;
-    case 1:
+    case TITLESET:
       mainDlg->checkTS(state,this);
       break;
     default :
@@ -402,22 +404,29 @@ void k9Main::Copy()
     m_playbackOptions->setSequence(); // JMP : temporaire
 
     k9DVDBackup *backup=new k9DVDBackup(dvd,"backup");
+    
+    setProgressWindow(backup->getDialog());
     backup->setOutput(m_prefOutput);
     backup->setDevice(dvd->getDevice());
     backup->setWithMenus( withMenus());
     backup->execute();
     burn=backup->getErrMsg()=="";
     delete backup;
+    removeProgressWindow();  
   }
   else
   {
     //k9DVDAuthor *b=static_cast<k9DVDAuthor  *>(m_factory->create(dvd,"dvdauthor", "k9DVDAuthor"));
+    
     k9DVDAuthor *b=new k9DVDAuthor(dvd,"dvdauthor");
+    setProgressWindow( b->getDialog());
     m_playbackOptions->setSequence();
     b->setworkDir(m_prefOutput);
     b->author();
     if (!b->getError())
       burn=true;
+    removeProgressWindow();
+    
     delete b;
   }
 
@@ -426,6 +435,8 @@ void k9Main::Copy()
     changeStatusbar(i18n("Burning DVD"),sbMessage);
 
     k9BurnDVD b;
+    
+    setProgressWindow( b.getDialog()); 
     b.setworkDir(m_prefOutput);
     b.setUseK3b(m_prefK3b);
     b.setAutoBurn(m_prefAutoBurn);
@@ -437,17 +448,36 @@ void k9Main::Copy()
       b.setburnDevice(drive->device);
       closeDVD();
       if (dvd->getDevice()== drive->device)
-        drives.eject(dvd->getDevice());
+        b.setAutoBurn(false);
     }
     else
       b.makeIso(filename);
     b.burn();
+    removeProgressWindow();
   }
   if(dvd->getopened())
     changeStatusbar(i18n("Ready"),sbMessage);
 
 }
 
+void k9Main::setProgressWindow(QWidget *_widget) {
+    m_toolView=m_parent->setToolWindow(_widget,KDockWidget::DockRight,i18n("processing"),i18n("processing"));
+    m_dockWidget = m_parent->getVisibleDock();
+    m_parent->setActions( false);
+    m_toolView->show();
+    this->setEnabled(false);
+ 
+}
+
+void k9Main::removeProgressWindow() {
+    m_parent->setActions(true);
+
+    m_parent->removeToolWindow( m_toolView);
+    this->setEnabled(true);
+    if (m_dockWidget!=NULL)
+    	m_dockWidget->changeHideShowState();
+}
+
 void k9Main::eject()
 {
   closeDVD();
@@ -503,9 +533,9 @@ void k9Main::Open()
   k9DVDTitle * l_track;
   QString t;
   QTime h;
-  connect(this, SIGNAL(sig_progress(QString)), this, SLOT(slot_progress(QString)));
   connect(listView1,SIGNAL(itemRenamed(QListViewItem*,int)),this,SLOT(itemRenamed(QListViewItem *,int)));
-
+  connect(listView1,SIGNAL(expanded( QListViewItem*)),this,SLOT(expanded( QListViewItem* )));
+  connect(listView1,SIGNAL(collapsed( QListViewItem*)),this,SLOT(collapsed( QListViewItem* )));
 
   closeDVD();
   QString sDevice=getDevice(cbInputDev);
@@ -539,26 +569,28 @@ void k9Main::Open()
   tsItems.clear();
   chItems.clear();
 
-  root = new ckLvItem (listView1,this );
+  root = new ckLvItem (listView1,this,ROOT );
   root->setOpen( TRUE );
   
   root->setText(0, dvd->getDVDTitle());
   root->setRenameEnabled(0,true);
   root->obj=NULL;
   root->streamType=NONE;
+  root->setPixmap(0,SmallIcon("dvd_unmount"));
 
   for (i=0;i<dvd->gettitlesetCount();i++)
   {
-    ckLvItem *tsItem = new ckLvItem(root,this);
+    ckLvItem *tsItem = new ckLvItem(root,this,TITLESET);
     tsItem->setOpen(TRUE);
     QString c;
     c=i18n("Titleset %1").arg(i+1);
     tsItem->setText(0,c);
-    tsItem->setText(1,"   "+dvd->gettitleset(i)->getsize_mb() +" " +i18n("mb"));
+    tsItem->setText(1,"   "+dvd->gettitleset(i)->getsize_mb() +" " +i18n("MB"));
     tsItem->obj=dvd->gettitleset(i) ;
     tsItem->streamType=NONE;
     tsItem->setRenameEnabled(0,false);
     tsItems.append(tsItem);
+    tsItem->setPixmap( 0,SmallIcon("folder"));
   }
 
   for (i=0;i<dvd->gettitleCount();i++)
@@ -586,19 +618,8 @@ void k9Main::setDVDSize()
 }
 
 
-/** No descriptions */
-void k9Main::slot_progress(QString str)
-{
-  //  log->setText(log->text() + "\n" +str);
-  //  qApp->processEvents();
-
-}
-
-
-
 k9Main::~k9Main()
 {
-  delete m_update;
   delete dvd;
 }
 
@@ -611,7 +632,7 @@ void k9Main::closeEvent( QCloseEvent* ce )
 
 void k9Main::addChapters(QListViewItem *_parent,k9DVDTitle *_title)
 {
-  LvItem *chapter = new LvItem(_parent,CHAPTERS);
+  LvItem *chapter = new LvItem(_parent,CHAPTER);
   chapter->setText(0, i18n("chapters"));
   chapter->setOpen( false);
   chapter->setPixmap(0,pxChapter);
@@ -619,9 +640,9 @@ void k9Main::addChapters(QListViewItem *_parent,k9DVDTitle *_title)
   int ch=0;
   for (int i=0;i< _title->getchapterCount();i++)
   {
-    ckLvItem *it =new ckLvItem(chapter,this);
+    ckLvItem *it =new ckLvItem(chapter,this,CHAPTER);
     it->setText(0,i18n("chapter %1").arg(++ch));
-    it->setText(1,i18n("%1 mb").arg((double)(_title->getChapter(i)->getsectors()) /512));
+    it->setText(1,i18n("%1 MB").arg((double)(_title->getChapter(i)->getsectors()) /512));
     it->streamType=CHAP;
     it->obj=_title->getChapter(i);
     chItems.append( it);
@@ -632,11 +653,11 @@ void k9Main::addChapters(QListViewItem *_parent,k9DVDTitle *_title)
     k9DVDTitle *title2=_title->getTitles().at(j);
     for (int i=0;i< title2->getchapterCount();i++)
     {
-      ckLvItem *it =new ckLvItem(chapter,this);
+      ckLvItem *it =new ckLvItem(chapter,this,CHAPTER);
       it->setText(0,i18n("chapter %1").arg(++ch));
       it->streamType=CHAP;
       it->obj=title2->getChapter(i);
-      it->setText(1,i18n("%1 mb").arg((double)(title2->getChapter(i)->getsectors()) /512));
+      it->setText(1,i18n("%1 MB").arg((double)(title2->getChapter(i)->getsectors()) /512));
       chItems.append( it);
       it->mainTitle=_title;
     }
@@ -658,19 +679,20 @@ void k9Main::addTitle(k9DVDTitle *track)
 
   listView1->setRootIsDecorated(true);
 
-  LvItem * itemTrack = new LvItem( tsItems.at(track->getVTS()-1),TITLES);
+  LvItem * itemTrack = new LvItem( tsItems.at(track->getVTS()-1),TITLE);
   itemTrack->setOpen( false );
   itemTrack->setText(col1,track->getname());
   itemTrack->setRenameEnabled(0,true);
+  itemTrack->setPixmap(col1,SmallIcon("title"));
   c.sprintf("%.2f ", track->gettotalsize_mb());
 
-  itemTrack->setText(col2,c+i18n("mb"));
+  itemTrack->setText(col2,c+i18n("MB"));
   itemTrack->obj=track;
 
   addChapters( itemTrack,track);
 
   ckLvItem *video;
-  video=new ckLvItem( itemTrack,this);
+  video=new ckLvItem( itemTrack,this,STREAM);
   video->streamType=VID;
   addListItem(track,video,VID);
   video->setOpen( false );
@@ -678,7 +700,7 @@ void k9Main::addTitle(k9DVDTitle *track)
   c.append (" - " + track->gettotallength().toString("h:mm:ss"));
   video->setText(col1, c);
   c.sprintf("%.2f ",  track->gettotalvideosize_mb());
-  video->setText(col2,c +i18n("mb"));
+  video->setText(col2,c +i18n("MB"));
   video->setPixmap(col1,pxVideo);
   video->obj=track;
 
@@ -689,15 +711,16 @@ void k9Main::addTitle(k9DVDTitle *track)
     c.append( l_auds->getlanguage() + " " +l_auds->getformat()+" " );
     ch.sprintf("%dch ",l_auds->getchannels());
     c.append(ch+l_auds->getfrequency()+" "+l_auds->getquantization());
-    ckLvItem * item = new ckLvItem( itemTrack,this);
+    ckLvItem * item = new ckLvItem( itemTrack,this,STREAM);
     item->streamType=AUD;
     item->language=l_auds->getlanguage();
     addListItem(l_auds,item,AUD);
     item->setText( col1,  c );
-    c.sprintf("%.2f mb",  l_auds->getsize_mb());
+    c=i18n("%1 MB").arg(l_auds->getsize_mb());
     item->setText( col2,c);
     item->setText( col3,l_auds->getcontent());
     item->setPixmap(col1,pxSound);
+    
     item->obj=track;
     item->stream=l_auds;
   }
@@ -706,19 +729,22 @@ void k9Main::addTitle(k9DVDTitle *track)
     l_sub=track->getsubtitle(i);
     c=i18n("subpicture %1 ").arg(i+1);
     c.append( l_sub->getlanguage());
-    ckLvItem * item = new ckLvItem( itemTrack,this);
+    ckLvItem * item = new ckLvItem( itemTrack,this,STREAM);
     item->streamType=SUB;
     item->language=l_sub->getlanguage();
     addListItem(l_sub,item,SUB);
     item->setText( col1,  c );
-    c.sprintf("%.2f mb",  l_sub->getsize_mb());
+    c=i18n("%1 MB").arg(l_sub->getsize_mb());
     item->setText( col2,c);
     item->setText( col3, l_sub->getcontent());
     item->setPixmap(col1,pxText);
+
     item->obj=track;
     item->stream=l_sub;
   }
 }
+
+
 /** No descriptions */
 void k9Main::updateSelection()
 {
@@ -756,7 +782,7 @@ void k9Main::updateSelection()
   }
   bool supdating=updating;
   updating=true;
-  for (int i=0;i<chItems.count();i++)
+  for (uint i=0;i<chItems.count();i++)
   {
     ckLvItem *it=chItems.at(i);
     k9DVDChapter *c=(k9DVDChapter*)it->obj;
@@ -959,7 +985,7 @@ void k9Main::checkAll(bool state)
 
 void k9Main::checkTS( bool _state,ckLvItem *_item )
 {
-  k9DVDTitleset *titleset = (k9DVDTitleset*)_item;
+  k9DVDTitleset *titleset = (k9DVDTitleset*)_item->obj;
   titleset->setselected(_state);
   k9DVDListItem *litem;
   updating=true;
@@ -981,9 +1007,27 @@ void k9Main::checkTS( bool _state,ckLvItem *_item )
   emit SelectionChanged(dvd,withMenus());
 }
 
+void k9Main::expanded( QListViewItem *item) {
+if (item->rtti()==1001)
+  {
+    ckLvItem *ckit = (ckLvItem*) item;
+    if (ckit->objectType==TITLESET)
+    	ckit->setPixmap( 0,SmallIcon("folder_open"));
+  }
+}
+
+void k9Main::collapsed( QListViewItem *item) {
+if (item->rtti()==1001)
+  {
+    ckLvItem *ckit = (ckLvItem*) item;
+    if (ckit->objectType==TITLESET)    
+       ckit->setPixmap( 0,SmallIcon("folder"));
+  }
+}
+
 
 /** No descriptions */
-void k9Main::itemRenamed(QListViewItem * item,int col)
+void k9Main::itemRenamed(QListViewItem * item,int )
 {
   k9DVDTitle *t=NULL;
   QString newText;
@@ -1018,56 +1062,18 @@ void k9Main::readSettings()
   k9Config config;
   config.read();
 
-//  KSimpleConfig settings("K9Copy");
-//  m_prefOutput=settings.readEntry("/dir/output",locateLocal("tmp","k9copy/",true));
-//  cbInputDev->setCurrentItem(settings.readEntry("/dev/input",0).toInt());
-//  cbOutputDev->setCurrentItem(settings.readEntry("/dev/output",0).toInt());
   m_prefOutput=config.getPrefOutput();
   cbInputDev->setCurrentItem(config.getInputDev());
   cbOutputDev->setCurrentItem(config.getOutputDev());
   m_prefK3b=config.getPrefK3b();
 
-  //m_prefK3b=settings.readEntry("/options/usek3b",0).toInt();
   m_prefAutoBurn=config.getPrefAutoBurn();
   m_quickScan=config.getQuickScan();
   m_prefSize=config.getPrefSize();
-  //m_prefAutoBurn=settings.readEntry("/options/autoburn",0).toInt();
-  //m_quickScan=settings.readEntry("/options/quickscan","1").toInt();
-  //m_prefSize=settings.readEntry("/options/dvdsize",QString("4400")).toInt();
-
   //fill the burn speed combo
   //cbOutputDevActivated( cbOutputDev->currentItem());
   cbOutputDevActivated( config.getOutputDev());
  
-  m_prefMp4Codec=config.getPrefMp4Codec();
-  m_prefMp4Size=config.getPrefMp4Size();
-  m_prefMp4NumberCD=config.getPrefMp4NumberCD();
-  m_prefMp4AudioBitrate=config.getPrefMp4AudioBitrate();
-  m_prefMp4Height=config.getPrefMp4Height();
-  m_prefMp4Width=config.getPrefMp4Width();
-  //m_prefMp4Codec=settings.readEntry("/mp4/codec",0).toInt();
-  //m_prefMp4Size=settings.readEntry("/mp4/size",QString("700")).toInt();
-  //m_prefMp4NumberCD=settings.readEntry("/mp4/numberCD",QString("1")).toInt();
-  //m_prefMp4Width=settings.readEntry("/mp4/width","640");
-  //m_prefMp4Height=settings.readEntry("/mp4/height","");
-  //m_prefMp4AudioBitrate=settings.readEntry("/mp4/audiobitrate","128");
-  m_codecAudio=config.getCodecAudio();
-  m_codecLabels=config.getCodecLabels();
-  m_codecVideo=config.getCodecVideo();
-  
-  //m_codecAudio=settings.readListEntry("mencoder/audio");
-  //m_codecLabels=settings.readListEntry("mencoder/labels");
-  //m_codecVideo=settings.readListEntry("mencoder/video");
-
-  if (m_prefMp4Codec -2 <=m_codecLabels.count())
-  {
-    QStringList::Iterator it=m_codecAudio.at(m_prefMp4Codec);
-    m_prefCodecAudio=*it;
-    it=m_codecVideo.at(m_prefMp4Codec);
-    m_prefCodecVideo=*it;
-    it=m_codecLabels.at(m_prefMp4Codec);
-    m_prefCodecLabel=*it;
-  }
 
   //m_useDvdAuthor=settings.readBoolEntry("/options/useDvdAuthor",true);
    m_useDvdAuthor=config.getUseDvdAuthor();
@@ -1078,10 +1084,6 @@ void k9Main::saveSettings()
   k9Config config;
   config.read();
 
-//  KSimpleConfig settings("K9Copy");
-//  settings.writeEntry("/dev/input",cbInputDev->currentItem());
-//  settings.writeEntry("/dev/output",cbOutputDev->currentItem());
-//  settings.writeEntry("/options/keepMenus",(int)withMenus());
   config.setInputDev(cbInputDev->currentItem());
   config.setOutputDev(cbOutputDev->currentItem());
   config.setKeepMenus(withMenus());
@@ -1151,9 +1153,11 @@ void k9Main::CreateMP4()
       QString name;
       if (filename=="")
          filename=KFileDialog::getSaveFileName (QDir::homeDirPath(),"*.avi", 0,i18n("Save file to disk"));
-
+      if (filename=="")
+         break;
     
       k9MP4Enc *mp4=new k9MP4Enc();
+      setProgressWindow( mp4->getDialog());
       if (cpt >0) {
 	QString ext=filename.section(".",-1);
         if (ext!="")
@@ -1166,15 +1170,25 @@ void k9Main::CreateMP4()
       	mp4->setFilename(filename);
 
       cpt++;	
+      k9TitleEncOpt * opt=t->getEncOpt();
       mp4->setDevice(dvd->getDevice());
-      mp4->setAudioBitrate(m_prefMp4AudioBitrate);
-      mp4->setCodec((k9MP4Enc::Codec) m_prefMp4Codec);
-      mp4->setSize( QString::number(m_prefMp4Size));
-      mp4->setNumberCD(QString::number(m_prefMp4NumberCD));
-      mp4->setWidth( m_prefMp4Width);
-      mp4->setHeight( m_prefMp4Height);
+      mp4->setAudioBitrate(opt->getAudioBr());
+      mp4->setVideoBitrate(opt->getVideoBr());
+      mp4->setCodec( opt->getCodec());
+      mp4->setAudioCodec(opt->getAudioCodec());
+      mp4->setSize(QString::number(opt->getMaxSize()));
+      mp4->setAudioGain(QString::number(opt->getAudioGain()));
+      mp4->setNumberCD(QString::number(opt->getNumParts()));
+      mp4->setWidth(opt->getWidth() );
+      mp4->setHeight(opt->getHeight());
+      mp4->set2Passes( opt->get2Passes());
+      mp4->setUseCache(opt->getUseCache());
       mp4->execute(t);
+      bool bStop=mp4->isCanceled();
       delete mp4;
+      removeProgressWindow();
+      if (bStop)
+        break;
     }
   }
   changeStatusbar( i18n("Ready") ,sbMessage);
@@ -1234,13 +1248,6 @@ void k9Main::readDrives()
   
   drives.scanDrives();
 
-/*
-  for (int i=0; i<drives.count();i++)
-  {
-    k9CdDrive *drive=drives.getDrive(i);
-    addDrive(drive);
-  }
-*/
 }
 
 
@@ -1299,6 +1306,7 @@ void k9Main::closeDVD()
 {
   //viewer->bStopClick();
   emit stopPreview();
+  emit changedTitle(NULL);
   emit SelectionChanged(NULL,withMenus());
   changeStatusbar( "",sbFactor);
   changeStatusbar( "",sbMessage);
@@ -1367,7 +1375,7 @@ void k9Main::fspDone()
   fspFinish=true;
 }
 
-void k9Main::foundMountPoint( const QString &mountPoint, unsigned long kBSize, unsigned long kBUsed, unsigned long kBAvail)
+void k9Main::foundMountPoint( const QString &, unsigned long , unsigned long , unsigned long kBAvail)
 {
   fspAvail=kBAvail;
 }
@@ -1436,12 +1444,14 @@ void k9Main::Clone(QString _input,QString _output)
 }
 
 void k9Main::updateFactor(){
-  m_update->updateFactor();
+
+ // m_update->updateFactor();
+  updateFactor_internal();
 }
 
 void k9Main::updateFactor_internal()
 {
-  if (dvd->getopened())
+  if (dvd->getopened() && m_mutex.tryLock())
   {
     updateSelection();
     setDVDSize();
@@ -1453,7 +1463,8 @@ void k9Main::updateFactor_internal()
       changeStatusbar("",sbFactor);
     else
       changeStatusbar( QString::number(dbfactor,'f',2),sbFactor);
-    SelectionChanged( dvd,withMenus());
+    emit SelectionChanged( dvd,withMenus());
+    m_mutex.unlock();
   }
 }
 
@@ -1462,4 +1473,4 @@ bool k9Main::withMenus()
   return m_playbackOptions->withMenus();
 }
 
-#include "k9main.moc"
\ No newline at end of file
+#include "k9main.moc"
