@@ -27,9 +27,10 @@
 #include <kfiledialog.h>
 #include <qlistbox.h>
 #include "k9copy.h"
+#include <qmutex.h>
 
 enum  eStreamType {SUB,AUD,VID,NONE,CHAP} ;
-enum  eObjectType {TITLES,CHAPTERS};
+enum  eObjectType {TITLE,CHAPTER,TITLESET,STREAM,ROOT};
 
 class LvItem : public QListViewItem {
 public:
@@ -60,24 +61,27 @@ class k9UpdateFactor;
 
 class ckLvItem : public QCheckListItem {
 public:
-    ckLvItem( QListViewItem *parent,k9Main *dlg)
+    ckLvItem( QListViewItem *parent,k9Main *dlg,eObjectType _objectType)
             : QCheckListItem( parent,"",QCheckListItem::CheckBox) {
         mainDlg=dlg;
         obj=NULL;
         stream=NULL;
         streamType=NONE;
         language="";
+        objectType=_objectType;
     }
-    ckLvItem( QListView *parent,k9Main *dlg)
+    ckLvItem( QListView *parent,k9Main *dlg,eObjectType _objectType)
             : QCheckListItem( parent,"",QCheckListItem::CheckBox) {
         mainDlg=dlg;
         obj=NULL;
         stream=NULL;
         streamType=NONE;
         language="";
+        objectType=_objectType;
     }
     eStreamType streamType;
-
+    eObjectType objectType;
+    
     k9Main *mainDlg;
     k9DVDTitle *mainTitle;
     QObject *obj;
@@ -146,6 +150,8 @@ private slots:
     virtual void updateFactor_internal();
     virtual void	   deviceAdded(k9CdDrive *_drive);
     virtual void	   deviceRemoved(k9CdDrive *_drive);
+    virtual void	   expanded(QListViewItem*);
+    virtual void	   collapsed (QListViewItem*);
 public slots:
     /*$PUBLIC_SLOTS$*/
     virtual void          PreviewTitle();
@@ -163,6 +169,7 @@ protected:
 
     void readDrives();
     void addDrive (k9CdDrive *_drive);
+    k9Copy *m_parent;
     QPtrList<ckLvItem> tsItems;
     QPtrList<ckLvItem> chItems;
     ckLvItem * root;
@@ -173,6 +180,7 @@ protected:
     QPixmap pxSound;
     QPixmap pxText;
     QPixmap pxChapter;
+    QMutex m_mutex;
     bool updating;
     bool fspFinish;
     long fspAvail;
@@ -189,21 +197,13 @@ protected:
     bool m_prefK3b;
     bool m_prefMenu;
     bool m_prefAutoBurn;
-    int  m_prefMp4Codec;
-    int  m_prefMp4Size;
-    int  m_prefMp4NumberCD;
-    QString  m_prefMp4Width;
-    QString  m_prefMp4Height;
-    QString  m_prefMp4AudioBitrate;
-    QStringList m_codecAudio;
-    QStringList m_codecLabels;
-    QStringList m_codecVideo;
-    QString m_prefCodecAudio,m_prefCodecVideo,m_prefCodecLabel;
     k9PlaybackOptions *m_playbackOptions;
     k9LangSelect *m_langSelect;
+    
+    KMdiToolViewAccessor *m_toolView;
+    KDockWidget *m_dockWidget;
 protected slots:
     /*$PROTECTED_SLOTS$*/
-    void slot_progress(QString str);
     void itemRenamed ( QListViewItem *item, int col );
 signals: // Signals
     /** No descriptions */
@@ -218,6 +218,9 @@ private:
     void fillLvLanguages();
     void updateLvLang(const eStreamType streamType,const QString & lang) ;
     long getFreeSpace(const QString & _path);
+    void setProgressWindow(QWidget *_widget);
+    void removeProgressWindow();
+
 	
 };
 
