@@ -55,9 +55,7 @@ static const KCmdLineOptions options[] = {
 	    { "initstatus" ,I18N_NOOP("initialize status file"),0},
 	    { "continue" ,I18N_NOOP("continue playing from last sector"),0},
 	    { "firstpass" ,I18N_NOOP("don't save status at end"),0},
-
-
-
+	    { "usecache" ,I18N_NOOP("save cell in a temporary file before encoding"),0},
             KCmdLineLastOption // End of options.
         };
 
@@ -103,29 +101,12 @@ int main(int argc, char **argv) {
 	QString chapterListArg(args->getOption("chapterlist"));
 	bool ffactor=args->isSet("ffactor");
         bool play= args->isSet("play");
-/*	
-        InputOptionArg="/dev/hdb";
-        play=true;
-	TitleNumber="4";
-	audioFilterArg="1";
-        chapterArg="2";
-	cellArg="1";
-        injectArg="/tmp/kde-jmp/inject";
-	vampsFactorArg ="1.00";
-	inputSizeArg="8192";
-	chapterSizeArg="8192";
-	injectArg="/tmp/kde-jmp/k9copy/k9v102718";
-	totalSizeArg="300320768";
-	dvdSizeArg="4613734400";
-*/	
         if (play) {
             k9play player;
 	    player.setinitStatus( args->isSet("initstatus"));
-	    //tmp
-//	    player.setinitStatus( true);
-
 	    player.setcontinue( args->isSet("continue"));
 	    player.setfirstPass(args->isSet("firstpass"));
+            player.setuseCache(args->isSet("usecache"));
             player.setDevice(InputOptionArg);
             player.setTitle(TitleNumber.toInt());
             player.setstartSector(startSectorArg);
